@@ -16,6 +16,11 @@ sub collection_format {
   $c->$cb($args, $CODE);
 }
 
+sub empty {
+  my ($c, $args, $cb) = @_;
+  $c->$cb('', $CODE);
+}
+
 sub get_headers {
   my ($c, $args, $cb) = @_;
 
@@ -74,6 +79,11 @@ sub update_pet {
   $c->$cb($RES, $CODE);
 }
 
+sub patch_pet {
+  my ($c, $args, $cb) = @_;
+  $c->$cb({}, 204);
+}
+
 sub with_defaults {
   my ($c, $args, $cb) = @_;
   $c->$cb({ip => $args->{ip}, x => $args->{x}});
