@@ -23,7 +23,7 @@ sub startup {
   # Swagger API endpoints
   # /api             *       api
   #   +/posts        POST    "store"
-  #   +/posts        GET     "index"
+  #   +/posts        GET     "list"
   #   +/posts/(:id)  PUT     "update"
   #   +/posts/(:id)  DELETE  "remove"
   #   +/posts/(:id)  GET     "show"
@@ -40,13 +40,17 @@ sub startup {
   # /posts/:id       DELETE  "remove_post"
   my $r = $self->routes;
   $r->get('/' => sub { shift->redirect_to('posts') });
-  $r->get('/posts')->to('posts#index');
+  $r->get('/posts')->to('posts#list');
   $r->get('/posts/create')->to('posts#create')->name('create_post');
   $r->post('/posts')->to('posts#store')->name('store_post');
   $r->get('/posts/:id')->to('posts#show')->name('show_post');
   $r->get('/posts/:id/edit')->to('posts#edit')->name('edit_post');
   $r->put('/posts/:id')->to('posts#update')->name('update_post');
   $r->delete('/posts/:id')->to('posts#remove')->name('remove_post');
+
+  require Swagger2::Editor;
+  my $editor = Swagger2::Editor->new(specification_file => $self->home->rel_file('api.json'));
+  $r->route('/editor')->detour(app => $editor);
 }
 
 1;
